@@ -39,7 +39,7 @@ Beam_engraver::do_try_music (Music *m)
 
       if (d == STOP && !beam_p_)
 	{
-	  m->warning (_ ("no beam to end"));
+	  m->warning (_ ("can't find start of beam"));
 	  return false;
 	}
       reqs_drul_[d ] = c;
@@ -50,12 +50,12 @@ Beam_engraver::do_try_music (Music *m)
 
 
 void
-Beam_engraver::do_process_requests ()
+Beam_engraver::do_process_music ()
 {
   if (reqs_drul_[STOP])
     {
       if (!beam_p_)
-	reqs_drul_[STOP]->warning (_("no beam to end"));
+	reqs_drul_[STOP]->warning (_("can't find start of beam"));
       prev_start_req_ =0;
       finished_beam_p_ = beam_p_;
       finished_beam_info_p_ = beam_info_p_;
@@ -84,7 +84,7 @@ Beam_engraver::do_process_requests ()
     {
       if (beam_p_)
 	{
-	  reqs_drul_[START]->warning (_ ("Already have a beam"));
+	  reqs_drul_[START]->warning (_ ("already have a beam"));
 	  return;
 	}
 
@@ -139,7 +139,7 @@ Beam_engraver::do_removal_processing ()
   typeset_beam ();
   if (beam_p_)
     {
-      prev_start_req_->warning (_ ("unfinished beam"));
+      prev_start_req_->warning (_ ("unterminated beam"));
       finished_beam_p_ = beam_p_;
       finished_beam_info_p_ = beam_info_p_;
       typeset_beam ();
@@ -167,7 +167,7 @@ Beam_engraver::acknowledge_element (Score_element_info info)
       Rhythmic_req *rhythmic_req = dynamic_cast <Rhythmic_req *> (info.req_l_);
       if (!rhythmic_req)
 	{
-	  String s = _ ("Stem must have Rhythmic structure");
+	  String s = _ ("stem must have Rhythmic structure");
 	  if (info.req_l_)
 	    info.req_l_->warning (s);
 	  else
@@ -178,8 +178,8 @@ Beam_engraver::acknowledge_element (Score_element_info info)
       
       if (rhythmic_req->duration_.durlog_i_<= 2)
 	{
-	  rhythmic_req->warning (_ ("Stem doesn't fit in beam"));
-	  prev_start_req_->warning (_ ("Beam was started here"));
+	  rhythmic_req->warning (_ ("stem doesn't fit in beam"));
+	  prev_start_req_->warning (_ ("beam was started here"));
 	  /*
 	    don't return, since
 
