@@ -123,7 +123,7 @@ read_lily_scm_file (String fn)
   String s = global_path.find (fn);
   if (s == "")
     {
-      String e = _f ("Can't find file: `%s'", fn);
+      String e = _f ("can't find file: `%s'", fn);
       e += " ";
       e += _f ("(load path: `%s')", global_path.str ());
       error (e);
@@ -146,7 +146,7 @@ ly_gulp_file (SCM name)
  String s = global_path.find (fn);
   if (s == "")
     {
-      String e = _f ("Can't find file: `%s'", fn);
+      String e = _f ("can't find file: `%s'", fn);
       e += " ";
       e += _f ("(load path: `%s')", global_path.str ());
       error (e);
