@@ -53,8 +53,8 @@ Lookup::afm_find (String s, bool warn) const
       me->afm_l_ = all_fonts_global_p->find_afm (font_name_);
       if (!me->afm_l_)
 	{
-	  warning (_f ("Can't find font: `%s'", font_name_));
-	  warning (_f ("(search path `%s')", global_path.str ().ch_C()));
+	  warning (_f ("can't find font: `%s'", font_name_));
+	  warning (_f ("(search path: `%s')", global_path.str ().ch_C()));
 	  error (_ ("Aborting"));
 	}
     }
@@ -285,6 +285,8 @@ Lookup::text (String style, String text, Paper_def *paper_l)
       lines[i] = str;
     }
 
+  if (!lines.size())
+	return Molecule();
 
   SCM first = gh_list (ly_symbol2scm ("text"),
 			 ly_str02scm (lines[0].ch_C()),
