@@ -57,7 +57,7 @@ protected:
   virtual void do_pre_move_processing ();
   virtual void acknowledge_element (Score_element_info);
   virtual bool do_try_music (Music*);
-  virtual void do_process_requests ();
+  virtual void do_process_music ();
   virtual void process_acknowledged ();
 
 public:
@@ -110,7 +110,7 @@ Tie_engraver::acknowledge_element (Score_element_info i)
 }
 
 void
-Tie_engraver::do_process_requests ()
+Tie_engraver::do_process_music ()
 {
   if (req_l_)
     {
